@@ -47,7 +47,11 @@ QT_BEGIN_NAMESPACE
 class QSvgIconPlugin : public QIconEnginePlugin
 {
     Q_OBJECT
+#ifndef QT_NO_COMPRESS
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QIconEngineFactoryInterface" FILE "qsvgiconengine.json")
+#else
+    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QIconEngineFactoryInterface" FILE "qsvgiconengine-nocompress.json")
+#endif
 
 public:
     QStringList keys() const;
